// List of available locales
const availableLocales = ['en', 'de', 'es', 'fr', 'it'];

// Default locale.
const defaultLanguage = 'en';

// Manually detect users' language to detect languages such as `en-GB`. Strip to `en`.
let language = (window.navigator.userLanguage || window.navigator.language).substr(0, 2);

// If `?lang=` exists in URL params & is valid, then use that instead.
const urlParams = new URLSearchParams(window.location.search);
const langFromUrl = urlParams.get('lang');
if (langFromUrl && availableLocales.includes(langFromUrl)) {
  language = langFromUrl
}

// Set `pageLanguage` only if its available within our locales, otherwise default.
let pageLanguage = defaultLanguage;
if (availableLocales.includes(language)) {
  pageLanguage = language;
}

// Locale translations.
const locales = {

  // EN
  en: {
    "marketing-disclosure": "Marketing Disclosure",
    "heading": "Security & Protection",
    "at-risk": "Protect This Android Phone",
    "at-risk_ios": "Are You Safe Browsing Online?",
    "alert": "Enable Protection",
    "title": "Install Protection App",
    "body": "An Increasing Amount of Websites Contain Harmful Viruses & Malware. It is Recommended to Protect your Smartphone with Antivirus Software",
    "body_ios": "Online Threats and Fake Websites are on the Rise. Safeguard Yourself Today with Security Software for Both You and Your Family",
    "cta": "Protect This Device",
    "cta_ios": "Get Protected Now",
    "app-security": "App Security",
    "app-security-scan": "Security Scan Recommended to Check Device",
    "app-security-scan_ios": "Check Device Compatibility Today",
    "app-security-scan-available": "Protection Available for this Device",
  },

  // DE
  de: {
    "marketing-disclosure": "Marketing-Transparenz",
    "heading": "Sicherheit & Schutz",
    "at-risk": "Schützen Sie dieses Android-Telefon",
    "at-risk_ios": "Sind Sie sicher beim Online-Browsen?",
    "alert": "Schutz aktivieren",
    "title": "Schutz-App installieren",
    "body": "Immer mehr Websites enthalten schädliche Viren und Malware. Es wird empfohlen, Smartphones mit einer Antivirensoftware zu schützen.",
    "body_ios": "Immer mehr Online-Bedrohungen und gefälschte Websites gefährden unsere Sicherheit. Schützen Sie sich noch heute mit Sicherheitssoftware für Sie und Ihre Familie.",
    "cta": "Gerät schützen",
    "cta_ios": "Jetzt schützen",
    "app-security": "App-Sicherheit",
    "app-security-scan": "Zur Überprüfung des Geräts wird ein Sicherheitsscan empfohlen",
    "app-security-scan_ios": "Jetzt Geräteverfügbarkeit prüfen",
    "app-security-scan-available": "Schutz für dieses Gerät verfügbar",
  },

  // ES
  es: {
    "marketing-disclosure": "Divulgación de marketing",
    "heading": "Seguridad y protección",
    "at-risk": "Proteja este teléfono Android",
    "at-risk_ios": "¿Estás seguro navegando en línea?",
    "alert": "Habilitar protección",
    "title": "Instalar aplicación de protección",
    "body": "Cada vez más páginas web contienen malware y virus dañinos. Le recomendamos que proteja su móvil con un programa antivirus",
    "body_ios": "Las amenazas en línea y los sitios web falsos están en aumento. Protégete hoy con software de seguridad tanto para ti como para tu familia.",
    "cta": "Proteger este dispositivo",
    "cta_ios": "Protégete ahora",
    "app-security": "Seguridad de la aplicación",
    "app-security-scan": "Análisis de seguridad recomendado para comprobar el dispositivo",
    "app-security-scan_ios": "Verifica la disponibilidad del dispositivo hoy.",
    "app-security-scan-available": "Protección disponible para este dispositivo",
  },

  // FR
  fr: {
    "marketing-disclosure": "Déclaration de marketing",
    "heading": "Sécurité et protection",
    "at-risk": "Protégez ce téléphone Android",
    "at-risk_ios": "Êtes-vous en sécurité lors de la navigation en ligne?",
    "alert": "Activer la protection",
    "title": "Installer l'appli de protection",
    "body": "De plus en plus de sites web contiennent des virus et des logiciels malveillants dangereux. Il est recommandé de protéger votre smartphone avec un logiciel antivirus",
    "body_ios": "Les menaces en ligne et les faux sites web sont en hausse. Protégez-vous dès aujourd'hui avec un logiciel de sécurité pour vous et votre famille",
    "cta": "Protégez cet appareil",
    "cta_ios": "Protégez-vous maintenant",
    "app-security": "Sécurité des applications",
    "app-security-scan": "Analyse de sécurité recommandée pour vérifier l'appareil",
    "app-security-scan_ios": "Vérifiez la disponibilité de l'appareil aujourd'hui",
    "app-security-scan-available": "Protection disponible pour cet appareil",
  },

  // IT
  it: {
    "marketing-disclosure": "Informativa di marketing",
    "heading": "Sicurezza e protezione",
    "at-risk": "Proteggi questo telefono Android",
    "at-risk_ios": "Sei al sicuro durante la navigazione online?",
    "alert": "Abilita protezione",
    "title": "Installa l'app di protezione",
    "body": "Un numero crescente di siti web contiene virus e malware dannosi. Si consiglia di proteggere lo smartphone con un software antivirus",
    "body_ios": "Minacce online e siti web falsi sono in aumento. Proteggiti oggi con un software di sicurezza per te e la tua famiglia.",
    "cta": "Proteggi questo dispositivo",
    "cta_ios": "Proteggiti ora",
    "app-security": "Sicurezza delle app",
    "app-security-scan": "Scansione di sicurezza consigliata per controllare il dispositivo",
    "app-security-scan_ios": "Verifica la disponibilità del dispositivo oggi.",
    "app-security-scan-available": "Protezione disponibile per questo dispositivo",
  },
};

// Get all page elements to be translated.
const elements = document.querySelectorAll('[data-i18n]');

// Get JSON object of translations.
const json = locales[pageLanguage];

// On each element, found the translation from JSON file & update.
elements.forEach((element, index) => {
  const key = element.getAttribute('data-i18n');
  const text = key.split('.').reduce((obj, i) => (obj ? obj[i] : null), json);
  element.innerHTML = text;
});
